/*
 * Copyright Elasticsearch B.V. and/or licensed to Elasticsearch B.V. under one
 * or more contributor license agreements. Licensed under the "Elastic License
 * 2.0", the "GNU Affero General Public License v3.0 only", and the "Server Side
 * Public License v 1"; you may not use this file except in compliance with, at
 * your election, the "Elastic License 2.0", the "GNU Affero General Public
 * License v3.0 only", or the "Server Side Public License, v 1".
 */

import { Plugin, CoreSetup } from '@kbn/core/server';

import { schema } from '@kbn/config-schema';

export class RenderingPlugin implements Plugin {
  public setup(core: CoreSetup) {
    core.http.resources.register(
      {
        path: '/render/{id}',
        validate: {
          query: schema.object(
            {
              isAnonymousPage: schema.boolean({ defaultValue: false }),
            },
            { unknowns: 'allow' }
          ),
          params: schema.object({
            id: schema.maybe(schema.string()),
          }),
        },
      },
      async (context, req, res) => {
        const { isAnonymousPage } = req.query;

        if (isAnonymousPage) {
          return res.renderAnonymousCoreApp({ includeExposedConfigKeys: true });
        }
        return res.renderCoreApp({ includeExposedConfigKeys: true });
      }
    );
  }

  public start() {}

  public stop() {}
}
